==> coreutils-9.9.tar.xz: coreutils-9.9/tests/nice/nice.sh <==
#!/bin/sh
# Test "nice".

# Copyright (C) 2002-2025 Free Software Foundation, Inc.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

. "${srcdir=.}/tests/init.sh"; path_prepend_ ./src
print_ver_ nice
getlimits_

tests='
0 empty 10
1 -1 1
2 -12 12
3 -1:-2 2
4 -n:1 1
5 -n:1:-2 2
6 -n:1:-+12 12
7 -2:-n:1 1
8 -2:-n:12 12
9 -+1 1
10 -+12 12
11 -+1:-+12 12
12 -n:+1 1
13 --1:-2 2
14 --1:-2:-13 13
15 --1:-n:2 2
16 --1:-n:2:-3 3
17 --1:-n:2:-13 13
18 -n:-1:-12 12
19 --1:-12 12
NA LAST NA
'
set -- $tests

# Require that this test be run at 'nice' level 0.
niceness=$(nice)
if test "$niceness" = 0; then
    : ok
else
  skip_ "this test must be run at nice level 0"
fi

while :; do
  test_name=$1
  args=$2
  expected_result=$3
  test $args = empty && args=''
  test x$args = xLAST && break
  args=$(echo x$args|tr : ' '|sed 's/^x//')
  if test "$VERBOSE" = yes; then
    #echo "testing \$(nice $args nice\) = $expected_result ..."
    echo "test $test_name... " | tr -d '\n'
  fi
  test x$(nice $args nice 2> /dev/null) = x$expected_result \
    && ok=ok || ok=FAIL fail=1
  test "$VERBOSE" = yes && echo $ok
  shift; shift; shift
done

# Test negative niceness - command must be run whether or not change happens.
if test x$(nice -n -1 nice 2> /dev/null) = x0 ; then
  # GNU/Hurd does not allow negative niceness even if we are a privileged user.
  if test "$(uname)" = GNU; then
    max_nice=$(nice -n "$INT_MAX" nice) || framework_failure_
    # Check that the lowest niceness is 0.
    nice -n -1 nice > out || fail=1
    echo '0' > exp || framework_failure_
    compare exp out || fail=1
    # Exceeding the max niceness would lead to the program not being executed on
    # GNU/Hurd with coreutils 9.8 and earlier.
    nice -n $(("$max_nice" + 1)) nice > out || fail=1
    echo "$max_nice" > exp || framework_failure_
    compare exp out || fail=1
    # GNU/Hurd's nice(2) with glibc 2.42 and earlier does not clamp the
    # niceness to the supported range.  Check that we workaround the bug.
    # See <https://sourceware.org/PR33614>.
    nice -n 1 nice -n $(("$max_nice" - 2)) nice > out|| fail=1
    echo $(("$max_nice" - 1)) > exp || framework_failure_
    compare exp out || fail=1
    nice -n 1 nice -n $(("$max_nice" + 1)) nice > out || fail=1
    echo "$max_nice" > exp || framework_failure_
    compare exp out || fail=1
    nice -n 2 nice -n -1 nice > out || fail=1
    echo '1' > exp || framework_failure_
    compare exp out || fail=1
    nice -n 2 nice -n -3 nice > out || fail=1
    echo '0' > exp || framework_failure_
    compare exp out || fail=1
  else
    # unprivileged user - warn about failure to change
    nice -n -1 true 2> err || fail=1
    compare /dev/null err && fail=1
    mv err exp || framework_failure_
    nice --1 true 2> err || fail=1
    compare exp err || fail=1
    # Failure to write advisory message is fatal.  Buggy through coreutils 8.0.
    if test "$(uname)" != GNU && test -w /dev/full && test -c /dev/full; then
      returns_ 125 nice -n -1 nice > out 2> /dev/full || fail=1
      compare /dev/null out || fail=1
    fi
  fi
else
  # superuser - change succeeds
  nice -n -1 nice 2> err || fail=1
  compare /dev/null err || fail=1
  test x$(nice -n -1 nice) = x-1 || fail=1
  test x$(nice --1 nice) = x-1 || fail=1
fi

Exit $fail

==> coreutils_9.10.orig.tar.xz: coreutils-9.10/tests/nice/nice.sh <==
#!/bin/sh
# Test "nice".

# Copyright (C) 2002-2026 Free Software Foundation, Inc.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

. "${srcdir=.}/tests/init.sh"; path_prepend_ ./src
print_ver_ nice
getlimits_

tests='
0 empty 10
1 -1 1
2 -12 12
3 -1:-2 2
4 -n:1 1
5 -n:1:-2 2
6 -n:1:-+12 12
7 -2:-n:1 1
8 -2:-n:12 12
9 -+1 1
10 -+12 12
11 -+1:-+12 12
12 -n:+1 1
13 --1:-2 2
14 --1:-2:-13 13
15 --1:-n:2 2
16 --1:-n:2:-3 3
17 --1:-n:2:-13 13
18 -n:-1:-12 12
19 --1:-12 12
NA LAST NA
'
set -- $tests

# Require that this test be run at 'nice' level 0.
niceness=$(nice)
if test "$niceness" = 0; then
    : ok
else
  skip_ "this test must be run at nice level 0"
fi

while :; do
  test_name=$1
  args=$2
  expected_result=$3
  test $args = empty && args=''
  test x$args = xLAST && break
  args=$(echo x$args|tr : ' '|sed 's/^x//')
  if test "$VERBOSE" = yes; then
    #echo "testing \$(nice $args nice\) = $expected_result ..."
    echo "test $test_name... " | tr -d '\n'
  fi
  test x$(nice $args nice 2> /dev/null) = x$expected_result \
    && ok=ok || ok=FAIL fail=1
  test "$VERBOSE" = yes && echo $ok
  shift; shift; shift
done

# Test negative niceness - command must be run whether or not change happens.
if test x$(nice -n -1 nice 2> /dev/null) = x0 ; then
  # GNU/Hurd does not allow negative niceness even if we are a privileged user.
  if test "$(uname)" = GNU; then
    max_nice=$(nice -n "$INT_MAX" nice) || fail=1
    # Check that the lowest niceness is 0.
    nice -n -1 nice > out || fail=1
    echo '0' > exp || framework_failure_
    compare exp out || fail=1
    # Exceeding the max niceness would lead to the program not being executed on
    # GNU/Hurd with coreutils 9.8 and earlier.
    nice -n $(("$max_nice" + 1)) nice > out || fail=1
    echo "$max_nice" > exp || framework_failure_
    compare exp out || fail=1
    # GNU/Hurd's nice(2) with glibc 2.42 and earlier does not clamp the
    # niceness to the supported range.  Check that we workaround the bug.
    # See <https://sourceware.org/PR33614>.
    nice -n 1 nice -n $(("$max_nice" - 2)) nice > out|| fail=1
    echo $(("$max_nice" - 1)) > exp || framework_failure_
    compare exp out || fail=1
    nice -n 1 nice -n $(("$max_nice" + 1)) nice > out || fail=1
    echo "$max_nice" > exp || framework_failure_
    compare exp out || fail=1
    nice -n 2 nice -n -1 nice > out || fail=1
    echo '1' > exp || framework_failure_
    compare exp out || fail=1
    nice -n 2 nice -n -3 nice > out || fail=1
    echo '0' > exp || framework_failure_
    compare exp out || fail=1
  else
    # unprivileged user - warn about failure to change
    nice -n -1 true 2> err || fail=1
    compare /dev/null err && fail=1
    mv err exp || framework_failure_
    nice --1 true 2> err || fail=1
    compare exp err || fail=1
    # Failure to write advisory message is fatal.  Buggy through coreutils 8.0.
    if test "$(uname)" != GNU && test -w /dev/full && test -c /dev/full; then
      returns_ 125 nice -n -1 nice > out 2> /dev/full || fail=1
      compare /dev/null out || fail=1
    fi
  fi
else
  # superuser - change succeeds
  nice -n -1 nice 2> err || fail=1
  compare /dev/null err || fail=1
  test x$(nice -n -1 nice) = x-1 || fail=1
  test x$(nice --1 nice) = x-1 || fail=1
fi

# Ensure large values are clamped
nice -n $UINTMAX_OFLOW nice || fail=1

Exit $fail
